==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkLabelPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkLabelPeer

// class file dependencies
// @dep_class b42ad28212d7bec4 gnu_java_awt_peer_gtk_GtkComponentPeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class b3ec53f2d46ba01f gnu_java_awt_peer_gtk_GtkLabelPeer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkComponentPeer

#include "gnu/java/awt/peer/gtk/GtkComponentPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkLabelPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkLabelPeer_H_

// Forward structure declarations
struct _jc_java_awt_Label$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$_init$4274442616a31251(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, struct _jc_java_awt_Label$object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$create$d37c73730c977304(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, struct _jc_java_lang_String$object *, jfloat);
extern jfloat _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$getGtkAlignment$586bdc8a9e8192f3(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jint);
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$gtkWidgetModifyFont$cbd31df1d0d5c3cd(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, struct _jc_java_lang_String$object *, jint, jint);
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$nativeSetAlignment$9b31b8e65197a71a(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jfloat);
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$setAlignment$08e6572c0eb540d5(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jint);
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$setNativeBounds$000d30fec88fc099(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jint, jint, jint, jint);
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$setText$2774cf9ec78ebefc(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$create$d37c73730c977304;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$getGtkAlignment$586bdc8a9e8192f3;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$gtkWidgetModifyFont$cbd31df1d0d5c3cd;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$nativeSetAlignment$9b31b8e65197a71a;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$setAlignment$08e6572c0eb540d5;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$setNativeBounds$000d30fec88fc099;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$setText$2774cf9ec78ebefc;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vmethods {
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *);
	void	(*create$d37c73730c977304)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, struct _jc_java_lang_String$object *, jfloat);
	jfloat	(*getGtkAlignment$586bdc8a9e8192f3)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jint);
	void	(*gtkWidgetModifyFont$cbd31df1d0d5c3cd)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, struct _jc_java_lang_String$object *, jint, jint);
	void	(*nativeSetAlignment$9b31b8e65197a71a)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jfloat);
	void	(*setAlignment$08e6572c0eb540d5)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jint);
	void	(*setNativeBounds$000d30fec88fc099)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jint, jint, jint, jint);
	void	(*setText$2774cf9ec78ebefc)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vmethods	gnu_java_awt_peer_gtk_GtkLabelPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_refs	gnu_java_awt_peer_gtk_GtkLabelPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkLabelPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkLabelPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkLabelPeer_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkLabelPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkLabelPeer

// class file dependencies
// @dep_class b42ad28212d7bec4 gnu_java_awt_peer_gtk_GtkComponentPeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class b3ec53f2d46ba01f gnu_java_awt_peer_gtk_GtkLabelPeer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkComponentPeer

#include "gnu/java/awt/peer/gtk/GtkComponentPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkLabelPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkLabelPeer_H_

// Forward structure declarations
struct _jc_java_awt_Label$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$_init$4274442616a31251(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, struct _jc_java_awt_Label$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$create$d37c73730c977304(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, struct _jc_java_lang_String$object *, jfloat) _JC_JCNI_ATTR;
extern jfloat _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$getGtkAlignment$586bdc8a9e8192f3(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$gtkWidgetModifyFont$cbd31df1d0d5c3cd(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$nativeSetAlignment$9b31b8e65197a71a(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jfloat) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$setAlignment$08e6572c0eb540d5(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$setNativeBounds$000d30fec88fc099(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method$setText$2774cf9ec78ebefc(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$create$d37c73730c977304;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$getGtkAlignment$586bdc8a9e8192f3;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$gtkWidgetModifyFont$cbd31df1d0d5c3cd;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$nativeSetAlignment$9b31b8e65197a71a;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$setAlignment$08e6572c0eb540d5;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$setNativeBounds$000d30fec88fc099;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$method_info$setText$2774cf9ec78ebefc;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vmethods {
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *) _JC_JCNI_ATTR;
	void	(*create$d37c73730c977304)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, struct _jc_java_lang_String$object *, jfloat) _JC_JCNI_ATTR;
	jfloat	(*getGtkAlignment$586bdc8a9e8192f3)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jint) _JC_JCNI_ATTR;
	void	(*gtkWidgetModifyFont$cbd31df1d0d5c3cd)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
	void	(*nativeSetAlignment$9b31b8e65197a71a)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jfloat) _JC_JCNI_ATTR;
	void	(*setAlignment$08e6572c0eb540d5)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jint) _JC_JCNI_ATTR;
	void	(*setNativeBounds$000d30fec88fc099)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
	void	(*setText$2774cf9ec78ebefc)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vmethods	gnu_java_awt_peer_gtk_GtkLabelPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_refs	gnu_java_awt_peer_gtk_GtkLabelPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkLabelPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkLabelPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkLabelPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkLabelPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkLabelPeer_H_ */
